import { LogLevel } from '@genesislcap/foundation-utils';
/**
 * Retrieves the notification details from an NotificationStructure object
 * @public
 * @param details - The NotificationStructure object
 * @returns The title and body concatenated as a string, or default values ('Error: Something went wrong') if not present
 */
export const getNotificationDetails = (details) => {
    const title = details?.title ?? 'Error';
    const body = details?.body ?? 'Something went wrong';
    return `${title}: ${body}`;
};
/**
 * Retrieves the log level from an NotificationStructure object
 * @public
 * @param details - The NotificationStructure object
 * @returns The log level or the default value (LogLevel.Debug) if not present
 */
export const getLoglevel = (details) => {
    return details?.logLevel || details?.config?.logLevel || LogLevel.Debug;
};
/**
 * Get/Create the error container in the DOM
 * @public
 * @param id - The id of the container
 * @param tagName - The tag name to create prefix for the design system provider
 * @returns
 */
export const getNotificationContainer = (id, tagName) => {
    const tagPrefix = tagName.split('-')[0];
    let container = document.querySelector(`#${id}`);
    if (!container) {
        container = document.createElement('div');
        container.setAttribute('id', id);
        const dsProvider = document.createElement(`${tagPrefix}-design-system-provider`);
        dsProvider.appendChild(container);
        document.body.appendChild(dsProvider);
    }
    return container;
};
/**
 * Get the banner anchor to attach the banner to
 * @public
 * @param element - The element to start searching from
 * @returns
 */
export const getBannerAnchor = (element) => {
    while (element && !(element instanceof ShadowRoot)) {
        const anchor = element?.getRootNode()?.getElementById('banner-anchor');
        if (anchor) {
            anchor.style.position = 'relative';
            return anchor;
        }
        element = element?.getRootNode()?.host;
    }
    return createBannerContainer();
};
const createBannerContainer = () => {
    const anchor = document.createElement('div');
    anchor.setAttribute('id', 'banner-anchor');
    anchor.style.position = 'relative';
    document.body.insertBefore(anchor, document.body.firstChild);
    return anchor;
};
